// 
// Copyright (C) 2007, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//

#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Enter the description of your strategy here
    /// </summary>
    [Description("Enter the description of your strategy here")]
    public class SampleHaltBasicStrategy : Strategy
    {
        #region Variables
		private IOrder myEntryOrder = null;
		private bool entrySubmit = false;
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose = true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// After our strategy has a PnL greater than $1000 or less than -$400 we will stop our strategy
			if (Performance.AllTrades.TradesPerformance.Currency.CumProfit > 1000 
				|| Performance.AllTrades.TradesPerformance.Currency.CumProfit < -400)
			{
				/* A custom method designed to close all open positions and cancel all working orders will be called.
				This will ensure we do not have an unmanaged position left after we halt our strategy. */
				StopStrategy();
				
				// Halt further processing of our strategy
				return;
			}
			
			/* This print will show every time the OnBarUpdate() method is called. When strategy is stopped it will
			no longer print. */
			Print("OnBarUpdate(): " + Time[0]);
			
			if (Close[0] > Open[0] && entrySubmit == false)
			{
				/* Submits a Long Limit order at the current bar's low. This order has liveUntilCancelled set to true
				so it does not require resubmission on every new bar to keep it alive. */ 
				myEntryOrder = EnterLongLimit(0, true, 1, Low[0], "Long Limit");
				
				// Set our bool to true to prevent resubmission of our entry order
				entrySubmit = true;
			}
			
			// After 5 bars have passed since entry, exit the position
			if (BarsSinceEntry() >= 5)
			{
				// Submit our exit order
				ExitLong();
			}
			
			// After our position is closed we can reset our bool to allow for entries again
			if (Position.MarketPosition == MarketPosition.Flat && entrySubmit)
			{
				// Reset our bool to false to allow for submission of our entry order
				entrySubmit = false;
			}
        }
		
		private void StopStrategy()
		{
			// If our Long Limit order is still active we will need to cancel it.
			if (myEntryOrder != null)
				CancelOrder(myEntryOrder);
			
			// If we have a position we will need to close the position
			if (Position.MarketPosition == MarketPosition.Long)
				ExitLong();			
			else if (Position.MarketPosition == MarketPosition.Short)
				ExitShort();
		}

        #region Properties
        #endregion
    }
}
